"""
about.py
"""

name = "steelconnection"
description = "Simplify access to the Riverbed SteelConnect CX REST API."
version = "1.1.8"  # update via bump_version.py
author = "Greg Mueller"
author_email = "steelconnection@grelleum.com"
copyright = "Copyright 2018-2020 Greg Mueller"
license = "MIT"
project_home = "https://github.com/grelleum/SteelConnection"
documentation = "https://steelconnection.readthedocs.io/"
